<?php
/**
 * Created by PhpStorm.
 * User: carinaoliveira
 * Date: 01/07/14
 * Time: 11:51
 */

namespace Fiscal\Logic\CalculoReceitaBruta;

use Indeterminado\Entities\Receitabruta;
use Fiscal\Entities\Notafiscal;

class ReceitaMensal {

    //Função que atualiza no banco os campos que foram alterados
    public static function atualizaRecMenCalcRecBrut($campos) {

        $db = \Setforms2\Runtime\Connection::getInstance();
        $db->getConn()->beginTransaction();
        $connection = \Setforms2\Shared\Registry::getEntityManager();

        try {
            $where = "    CDEMPRESA =?
                      AND CDSIMPLESNACIONAL = ?
                      AND ( (TO_CHAR(DTREFRECEITABR, 'DD/MM/YYYY') = ?) OR (TO_CHAR(DTREFRECEITABR, 'DD/MM/YYYY hh24:mi:ss') = ?) )
                      AND NRORG = ?";

            $params = array($campos['CDEMPRESA'],$campos['CDSIMPLESNACIONAL'],$campos['DTREFRECEITABR'], $campos['DTREFRECEITABR'], $campos['NRORG']);

            $recmen = Receitabruta::getObjectsByWhere($where, $params);

            $recmen[0]->setVrsaldocompoe($campos['VRSALDOCOMPOE']);
            $recmen[0]->setVrsaldodeduz($campos['VRSALDODEDUZ']);
            $recmen[0]->setVrreceitabr($campos['VRRECEITABR']);
            $recmen[0]->setVrsaldonegmes($campos['VRSALDONEGMES']);
            $recmen[0]->setIdstatusmes($campos['IDSTATUSMES']);
            $recmen[0]->setIdinfmanual($campos['IDINFMANUAL']);
            $recmen[0]->setCdoperinclusao($campos['CDOPERINCLUSAO']);
            $recmen[0]->setDtultatu($campos['DTULTATU']);
            $recmen[0]->setDtinclusao($campos['DTINCLUSAO']);
            $recmen[0]->setNrorgultatu($campos['NRORGULTATU']);
            $recmen[0]->setCdoperultatu($campos['CDOPERULTATU']);
            $recmen[0]->setNrorginclusao($campos['NRORGINCLUSAO']);

            $recmen[0]->persist();

            $connection->flush();
            $db->commit();

        } catch (\Exception $e) {
            $db->rollback();
        }
    }

    public static function atualizaDataNFCalcRecBrut($cdfilialNotaF, $nrNotaF, $dtrefreceitabr) {
        $db = \Setforms2\Runtime\Connection::getInstance();
        $db->getConn()->beginTransaction();
        $connection = \Setforms2\Shared\Registry::getEntityManager();

        try {
            $where = "    CDFILIAL   = ?
                      AND NRLANCTONF = ?";

            $params = array($cdfilialNotaF, $nrNotaF);

            $notaF = Notafiscal::getObjectsByWhere($where, $params);

            $notaF[0]->setDtcalcrecbruta($dtrefreceitabr);

            $notaF[0]->persist();

            $connection->flush();
            $db->commit();

        } catch (\Exception $e) {
            $db->rollback();
        }
    }

    //Verifica se o registro a ser inserido ja existe na tabela
    public static function exiteRecMen($cdempresa, $cdsimplesnac, $dtrefreceitabr, $nrorg) {

        $where = "    CDEMPRESA =?
                  AND CDSIMPLESNACIONAL = ?
                  AND ( (TO_CHAR(DTREFRECEITABR, 'DD/MM/YYYY') = ?) OR (TO_CHAR(DTREFRECEITABR, 'DD/MM/YYYY hh24:mi:ss') = ?) )
                  AND NRORG = ?";

        $params = array($cdempresa, $cdsimplesnac, $dtrefreceitabr, $dtrefreceitabr, $nrorg);

        $recmen = Receitabruta::getObjectsByWhere($where, $params);

        if(count($recmen) > 0) {
            $existe = true;
        }
        else {
            $existe = false;
        }

        return $existe;
    }

    //Insere no banco uma nova Receita Mensal
    public static function insereRecMen($campos) {
        $db = \Setforms2\Runtime\Connection::getInstance();
        $db->getConn()->beginTransaction();
        $connection = \Setforms2\Shared\Registry::getEntityManager();

        $sucesso = false;

        try {
            $recmen = new Receitabruta();

            $recmen->setCdempresa($campos['CDEMPRESA']);
            $recmen->setCdsimplesnacional($campos['CDSIMPLESNACIONAL']);
            $recmen->setDtrefreceitabr($campos['DTREFRECEITABR']);
            $recmen->setVrsaldocompoe($campos['VRSALDOCOMPOE']);
            $recmen->setVrsaldodeduz($campos['VRSALDODEDUZ']);
            $recmen->setVrreceitabr($campos['VRRECEITABR']);
            $recmen->setVrsaldonegmes($campos['VRSALDONEGMES']);
            $recmen->setIdstatusmes($campos['IDSTATUSMES']);
            $recmen->setIdinfmanual($campos['IDINFMANUAL']);
            $recmen->setNrorg($campos['NRORG']);
            $recmen->setIdativo($campos['IDATIVO']);
            $recmen->setCdoperinclusao($campos['CDOPERINCLUSAO']);
            $recmen->setDtultatu($campos['DTULTATU']);
            $recmen->setDtinclusao($campos['DTINCLUSAO']);
            $recmen->setNrorgultatu($campos['NRORGULTATU']);
            $recmen->setCdoperultatu($campos['CDOPERULTATU']);
            $recmen->setNrorginclusao($campos['NRORGINCLUSAO']);

            $recmen->persist();

            $connection->flush();
            $db->commit();

            $sucesso = true;

        } catch (\Exception $e) {
            $db->rollback();
        }

        return $sucesso;

    }

    public static function deletaRecMen($cdempresa, $cdsimplesnac, $dtrefreceitabr) {

        $db = \Setforms2\Runtime\Connection::getInstance();
        $db->getConn()->beginTransaction();
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        $sucesso = false;

        try {

            $where = "    CDEMPRESA = ?
                      AND CDSIMPLESNACIONAL = ?
                      AND DTREFRECEITABR = ?";

            $params = array($cdempresa, $cdsimplesnac, $dtrefreceitabr);

            $recmen = Receitabruta::getObjectsByWhere($where, $params);

            $recmen[0]->delete(); //deleta receita mensal

            $connection->flush();
            $db->commit();

            $sucesso = true;

        } catch (\Exception $e) {

            $db->rollback();
        }

        return $sucesso;

    }

} 